@@ -53,10 +53,8 @@ static GtkCssValue *
 gtk_css_value_ease_compute (GtkCssValue             *value,
                             guint                    property_id,
                             GtkStyleProviderPrivate *provider,
-			    int                      scale,
-                            GtkCssStyle    *values,
-                            GtkCssStyle    *parent_values,
-                            GtkCssDependencies      *dependencies)
+                            GtkCssStyle             *style,
+                            GtkCssStyle             *parent_style)
 {
   return _gtk_css_value_ref (value);
 }
