@@ -193,6 +193,7 @@ gtk_gesture_single_handle_event (GtkEventController *controller,
       break;
     case GDK_TOUCH_CANCEL:
     case GDK_GRAB_BROKEN:
+    case GDK_TOUCHPAD_SWIPE:
       return GTK_EVENT_CONTROLLER_CLASS (gtk_gesture_single_parent_class)->handle_event (controller,
                                                                                          event);
       break;
@@ -510,7 +511,7 @@ gtk_gesture_single_get_current_button (GtkGestureSingle *gesture)
  * Returns the event sequence currently interacting with @gesture.
  * This is only meaningful if gtk_gesture_is_active() returns %TRUE.
  *
- * Returns: the current sequence
+ * Returns: (nullable): the current sequence
  *
  * Since: 3.14
  **/
